/* 
 * i-scream central monitoring system
 * http://www.i-scream.org
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.core.loggers;

//---IMPORTS---
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.core.*;
import java.util.Date;
import java.text.DateFormat;
import java.util.Locale;
import java.awt.Frame;
import java.awt.TextArea;
import java.awt.GridLayout;

/**
 * The SimpleGUILogger is an implementation of the LoggerImpl defined
 * in the associated interface. It's only purpose is to simply print
 * all the logging information it receives to a window frame.
 *
 * All very simple really...
 *
 * This class does have the problem that if too many messages are
 * entered into the text area, then it will fill the memory of
 * the JVM.  This MAY have been fixed by adding the setRows(int)
 * in the write(string) method, however the Java API does not
 * specify if this enforces the max rows, but I THINK it does.
 *
 * @author  $Author: tdb $
 * @version $Id: SimpleGUILogger.java,v 1.12 2004/08/01 10:40:56 tdb Exp $
 */
public class SimpleGUILogger implements LoggerImpl {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public final String REVISION = "$Revision: 1.12 $";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

    /**
     * Creates a new ScreenLoggerServant.
     */
    public SimpleGUILogger() {
    	_maxMessages = Integer.parseInt(System.getProperty("uk.org.iscream.cms.server.LoggerClass.SimpleGUILogger.maxMessages"));
    	
    	getFrame().add(getTextArea());
        getFrame().setSize(500,500);
        getFrame().setVisible(true);
    	
    	write(toString(), Logger.SYSINIT, "started");
    }

//---PUBLIC METHODS---

    /**
	 * The write() method takes a line of text, pre-formatted
	 * and outputs it using a method defined by the actual
	 * implementation. The verbosity is given in case the
	 * implementation wishes to utilise it in the layout -
	 * eg. a different colour or font.
	 * 
	 * This instance writes the line to a simple GUI message
	 * window.
	 * 
	 * @param line A line of formatted text to be logged
	 * @param verbosity the verbosity of this message
	 */  
    public synchronized void write(String line, int verbosity) {
        getTextArea().append(line + "\n");
        getTextArea().setRows(_maxMessages);
    }
       
   /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.FormatName class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }
    
//---PRIVATE METHODS---

    /**
     * This method is provided if this class wishes to log
     * a message itself.
     *
	 * @param source A String representation of the source
	 * @param verbosity the verbosity of this message
	 * @param message The message to log
	 */  
    private void write(String source, int verbosity, String message) {
        write(FormatName.formatLogLine(source, verbosity, message), verbosity);
    }

//---ACCESSOR/MUTATOR METHODS---

    /**
     * An accessor for the frame
     *
     * @return the frame for this class
     */
    private Frame getFrame(){
        return frame;
    }

    /**
     * an accessor for the text area
     *
     * @return the text area
     */
    private TextArea getTextArea(){
        return textArea;
    }

//---ATTRIBUTES---
   
    /**
     * a frame
     */
    private Frame frame = new Frame("I-SCREAM LOGGER");

    /**
     * a text area
     */
    private TextArea textArea = new TextArea(100,100);
	 
    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = Core.NAME;
    
    /**
     * The maximum number of messages that can
     * be displayed before bottom items are removed.
     * This is needed to fix the memory overload problem
     * that was seen when the GUI got too full!
     */
    private int _maxMessages;
    
//---STATIC ATTRIBUTES---
    
}
